Django-Frontend-Notification
============================

Django application to display on the frontend the list of notifications and run some basic actions such as "view all notifications", "delete notifications", it also provides helpers to display notifications.

This works with twitter bootstrap (http://twitter.github.com/bootstrap/) but can easily be adapted with other front-end frameworks.


.. image:: https://github.com/areski/django-frontend-notification/raw/master/docs/source/_static/django-frontend-notification.png


Documentation
=============

Extensive documentation is available on 'Read the Docs':
http://django-frontend-notification.readthedocs.org


Contributing
============

If you've found a bug, implemented a feature or customized the template and
think it is useful then please consider contributing. Patches, pull requests
and suggestions are welcome!

Source code: http://github.com/areski/django-frontend-notification

If you don’t like Github and Git you’re welcome to send regular patches.

Bug tracker: https://github.com/areski/django-frontend-notification/issues


License
=======

Copyright (c) 2011-2012 Star2Billing S.L. <info@star2billing.com>

django-frontend-notification is licensed under MIT, see `MIT-LICENSE.txt`.


Credit
======

django-frontend-notification is a Star2Billing-Sponsored Community Project, for more information visit
http://www.star2billing.com  or email us at info@star2billing.com
